@@ -21,8 +21,8 @@ def start_example_task(args=None, test=False):
 
     task_name, arguments = ComplexArguments(argument_objs).parse(args)
     if test: arguments.model_args.unit_test = test
-    log.info("Start Example Task:{}, with arguments:{}".format(task_name, str(arguments.taskArgs)))
-    task_action = arguments.runArgs.action
-    task_instance = TASKS[task_name](arguments.taskArgs)
+    log.info("Start Example Task:{}, with arguments:{}".format(task_name, str(arguments)))
+    task_action = arguments.action
+    task_instance = TASKS[task_name](arguments)
 
     eval('task_instance.' + task_action + '()')
