@@ -3,4 +3,4 @@ import sys
 from . import start_example_task
 
 if __name__ == "__main__":
-    start_example_task(sys.argv[1:])
+    start_example_task()
